#
# spec file for package python-findpython
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-findpython
Version:        0.6.2
Release:        1.2
Summary:        Utility to find python versions on your system
License:        MIT
URL:            https://github.com/frostming/findpython
Source:         https://files.pythonhosted.org/packages/source/f/findpython/findpython-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module packaging >= 20}
BuildRequires:  %{python_module pdm-backend}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
Requires(post): update-alternatives
Requires(postun): update-alternatives
Requires:       python-packaging >= 20
%python_subpackages

%description
Discover which versions of the Python interpreter are present on your
system.

%prep
%autosetup -p1 -n findpython-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/findpython
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative findpython

%postun
%python_uninstall_alternative findpython

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/findpython
%{python_sitelib}/findpython
%{python_sitelib}/findpython-%{version}*-info

%changelog
* Tue Oct 22 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.2:
  * Don't skip symlinks for rye provider
  * **ci**: Macos for old python versions
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.6.1:
  * Ignore invalid version strinig from winreg
- update to 0.6.0:
  * Support find by implementation
- update to 0.5.0:
  * Add implementation property
  * Drop support for python 3.7
  * Find rye pythons with and without install directory
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- drop revert-back-to-pdm-pep517.patch:
  try to resolve build cycle differently
* Mon Dec 11 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update 0.4.1:
  * feat: provider selector by @frostming in #20
  * feat: add support for RyeProvider
  * feat: Add way to filter providers by @bluss in #18
  * feat: add register_provider function and change ALL_PROVIDERS to a map
  * fix: don't import site-packages when running in-process scripts
  * Make GET_VERSION_TIMEOUT settable via env vars
  * Support allow_prereleases option
- Add patch revert-back-to-pdm-pep517.patch:
  * We need to use pdm-pep517, to avoid circular requirements.
* Thu Jun 15 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Wed May 10 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.5:
  * UTF-8 encoding of shell command output on Windows
  * Findpython failed if PATH env contains folder
    with restricted access
* Tue Jan 31 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.4:
  * Check path access before is_dir to prevent PermissionError exceptions
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.3:
  * Strip the local part in python version Fix #12
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.2.2
  * Prevent find_all exception when a clean pyenv is present  -  by @ferminho in #11
  * Don't parse as LegacyVersion  -  by @frostming (e3466)
* Mon Aug 15 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.2.1
  * Fix the python detection logic to try the fast method first
- Release 0.2.0
  * Allow provider to keep symlink even when resolve_symlinks is
    True
- Fix requirements
* Tue Jun 14 2022 Steve Kowalik <steven.kowalik@suse.com>
- Initial packaging for findpython 0.1.6.
